:
#
# version 3.0 Sep 25 11:21:02 PDT 1998
# version 3.1.4 Sep 12 09:21:02 PDT 1999

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt
# Archibald, and Dan Farmer 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000

# # The copyright holder disclaims all responsibility or liability with
# respect to its usage or its effect upon hardware or computer
# systems, and maintains copyright as set out in the "LICENSE"
# document which accompanies distribution.
#
 
 
TITANHOME=`pwd`
MYNAME=`basename $0`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
DATE=`/bin/date +%m%d%y%H%M`
RUNDATE=`/usr/bin/date +%Y%m%d%H%M`
OS=`uname -r`

CRONLOGDIR="/var/cron"
CRONDFILE="/etc/default/cron"
CRONLCHK="/etc/cron.daily/logrotate"
CRONDENY="/etc/cron.deny"
CRONALLOW="/etc/cron.allow"


# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

. misc_functions.sh
 
Intro() {
cat << EOF_INTRO
This script checks/puts CRONLOG=YES in /etc/default/cron,
changes the permissions of /var/cron so that the users cannot
peek in the cron log file (it seems the file is created with 600
perms anyhow, but one never knows), and modifies /etc/cron.daily/logchecker
to rotate the log files at 2MB file size.

For linux this creates /etc/cron.allow and adds only root by default.
All other local password accounts are added to /etc/cron.deny.

EOF_INTRO
}

Check() {

#Check whether cron logging is enabled. Take no chances, there
#must be exactly ONE CRONLOG= line which must be CRONLOG=YES

   if [ -r "$CRONDFILE" ] && \
      [ "`grep -cs '^CRONLOG=YES' $CRONDFILE`" -eq 1 ] && \
      [ "`grep -cs '^[^#]*CRONLOG=' $CRONDFILE`" -eq 1 ];then 
       t_echo 2 "   CRONLOG entry found - PASSES CHECK "
   else
      t_echo 0 "  CRONLOG entry not found or misconfigured - FAILS CHECK" 
   fi

#Check the perms of the cron log dir

   if [ -d "$CRONLOGDIR" ] && \
      ls -dl $CRONLOGDIR | grep -s "^drwx------" > /dev/null 2>&1
      then
       t_echo 2 "   $CRONLOGDIR permissions - PASSES CHECK " 
      else
       t_echo 0 "   $CRONLOGDIR permissions - FAILS CHECK " 
      fi

#Check whether the cron log files will be rotated when exceeding 2MB,
#one can find sometime sites with log files > 100MB

  if [ -r "$CRONLCHK" ] &&  grep "LIMIT=4096" $CRONLCHK > /dev/null 2>&1 ; 
      then
       t_echo 2 "   $CRONLCHK LIMIT - PASSES CHECK "
      else
       t_echo 0 "   $CRONLCHK LIMIT - FAILS CHECK "
      fi   

# Check is /etc/cron.deny and cron.allow exist. If so make sure root is the only
# entry on /etc/cron.allow and all other users are mirated to /etc/cron.deny.
# Add all remaining users from local /etc/passwd to /etc/cron.deny to tighten things
# up just a bit more.

if [ -r "$CRONALLOW" ]; then
 if [ `grep root "$CRONALLOW"` ]; then
       t_echo 2 "   $CRONALLOW LIMITED TO ROOT - PASSES CHECK "
      else
       t_echo 0 "   $CRONALLOW NOT LIMITED TO ROOT - FAILS CHECK "
fi
else
       t_echo 2 "   $CRONALLOW DOES NOT EXIST - FAILS CHECK"
fi

if [ -r "$CRONDENY" ]; then
       t_echo 2 "   $CRONDENY EXISTS - PASSES CHECK "
      else
       t_echo 0 "   $CRONDENY NOT FOUND - FAILS CHECK "
fi
  
}


Fix() {

   if [ -r "$CRONDFILE" ] && \
      [ "`grep -cs '^CRONLOG=YES' $CRONDFILE`" -eq 1 ] && \
      [ "`grep -cs '^[^#]*CRONLOG=' $CRONDFILE`" -eq 1 ];then 
       t_echo 2 "   CRONLOG entry found : PASSES CHECK "
   else
      t_echo 0 "  CRONLOG entry not found or misconfigured - FAILS CHECK" 
      t_echo 0 "  Fixing $CRONDFILE now...." 
        if [ ! -f "$CRONDFILE" ];then
            touch "$CRONDFILE" && chmod 444 "$CRONDFILE" \
            && chown root "$CRONDFILE" &&  chgrp sys "$CRONDFILE"
        else
        cp -p "$CRONDFILE" $CRONDFILE.${RUNDATE}
        fi
	ed - "$CRONDFILE" <<- __INPUT__ 
	g/^[^#]*CRONLOG=/d
	a
	CRONLOG=YES
	.
	w
	q
	__INPUT__
      echo "CRONLOG=YES" >>$CRONDFILE
      if [ "$?" -ne 0 ];then
        t_echo 0 "  Fixing $CRONDFILE FAILED - ERROR check the file" 
        exit 1
      fi
   fi


#Check the perms of the cron log dir

   if [ -d "$CRONLOGDIR" ] && \
      ls -dl $CRONLOGDIR | grep -s "^drwx------" > /dev/null 2>&1
      then
       t_echo 2 "   $CRONLOGDIR permissions - PASSES CHECK " 
      else
       t_echo 0 "   $CRONLOGDIR permissions - FAILS CHECK " 
       t_echo 0 "   Fixing the $CRONLOGDIR permissions ... " 
       if [ -d "$CRONLOGDIR" ]; then :
       else
         mkdir -p /var/cron
       fi
         chmod  700 /var/cron && chown root /var/cron \
         && chgrp sys /var/cron
   fi

#Check whether the cron log files will be rotated when exceeding 2MB,
#one can find sometime sites with log files > 100MB

  if [ -r "$CRONLCHK" ] &&  grep "LIMIT=4096" $CRONLCHK > /dev/null 2>&1 ; 
      then
       t_echo 2 "   $CRONLCHK LIMIT - PASSES CHECK "
      else
      t_echo 0 "   $CRONLCHK LIMIT - FAILS CHECK "
      t_echo 0 "  Fixing $CRONLCHK now...." 

      if [ -r "$CRONLCHK" ];then
      cp -p "$CRONLCHK" "$CRONLCHK".${DATE} && \
	ed "$CRONLCHK" <<- __INPUT__ 
	g/^LIMIT=\`ulimit\`/s/LIMIT=\`ulimit\`/LIMIT=4096/
	.
	w
	q
	__INPUT__
         if [ "$?" -ne 0 ];then
              t_echo 0 "   $CRONLCHK LIMIT - ERROR fix failed "
         fi   
      else
        t_echo 0 "  $CRONLCHK missing! " 
      fi
   fi

if [ -r "$CRONALLOW"  ]; then
  cp $CRONALLOW $CRONALLOW.${RUNDATE}
  echo "root" >/etc/cron.allow
  /bin/chmod 440 $CRONALLOW
 else
  echo "root" >/etc/cron.allow
  /bin/chmod 440 $CRONALLOW
fi 

if [ -r "$CRONDENY" ]; then
  cp $CRONDENY $CRONDENY.${RUNDATE}
  awk -F":" '{print $1}' /etc/passwd | grep -v root >$CRONDENY
  cat $CRONDENY.${RUNDATE} $CRONALLOW.${RUNDATE} $CRONDENY | sort -u >$CRONDENY
  /bin/chmod 440 $CRONDENY
else
  awk -F":" '{print $1}' /etc/passwd | grep -v root >$CRONDENY
  cat $CRONDENY.${RUNDATE} $CRONALLOW.${RUNDATE} $CRONDENY | sort -u >$CRONDENY
  /bin/chmod 440 $CRONDENY
fi

}

 
action=$1
case $action in
 -[Ff]*)
Fix
;;
 -[Vv]*)
Check
;;
 -[Ii]*)
Intro
;;
 
*)
        echo "        ERROR:Invalid arg $action"
        echo "        ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
 
        echo " "
;;
esac



# List all files to save prior to changes this modules might make.
# Syntax is SAVEFILES='foo bar foobar'
#
SAVEFILES='/etc/default/cron /etc/cron.daily/logrotate'
