:
# sendmail.sh
# version 3.0 Sep 25 11:21:02 PDT 1998
# Revision 3.1.4 changed by:brad powell Mon Sep 28 11:46:19 PDT 1998
# Changed by Mitko Stoyanov 03 Sep 1999 - add LogLevel checks and
# checks for Opgoaway whether it is already there
# version 3.4 Wed Feb 16 08:33:18 PST 2000 savefile variable added
# version 4.0.10 Fri Apr  6 07:47:10 PDT 2001

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt 
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001
#
# The copyright holder disclaims all responsibility or liability with 
# respect to its usage or its effect upon hardware or computer 
# systems, and maintains copyright as set out in the "LICENSE" 
# document which accompanies distribution. 

# setup
TITANHOME=`pwd`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
DATE=`/bin/date +%m%d%y%H%M`
SAVEFILES='/etc/mail/sendmail.cf'
OS=`uname -r`

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

#
# suck in some lib functions (t_echo, etc.)
#
. misc_functions.sh

Intro() {

cat << EOF
 $MYNAME : Adds the following flag to /etc/mail/sendmail.cf.
 This flag stops nosey persons from connecting to port
 25 and using expn and vrfy to gather information.

     # privacy flags
     # O PrivacyOptions=authwarnings,goaway
     Opgoaway
     # O PrivacyOptions=noexpn, novrfy, authwarnings
     O LogLevel=5

	Additionally checks for /sbin/smrsh and fixes sendmail.cf if it finds it
	if you don't have smrsh get it! supplement to the CERT advisory 
        CA-93:16.sendmail.vulnerability

EOF
}

Check() {
if [ -f /etc/mail/sendmail.cf ]; then
 
 if [ -f /etc/mail/sendmail.cf.titan2 ]; then
 
  t_echo 3 "       File /etc/mail/sendmail.cf.titan2 exists - Checking content"

  grep "^Opgoaway" /etc/mail/sendmail.cf >/dev/null

  if [ $? -ne 0 ]; then
   t_echo 0 "      A config file is in place but doesn't have Opgoaway set - FAILS CHECK"
   exit 1
  else
   t_echo 1 "      The Opgoaway option is in place - PASSES CHECK"
  fi
 
 else
   t_echo 0 "      No sendmail.cf.titan2 exists - FAILS CHECK"

 fi
 
else
 t_echo 1 ""
 t_echo 2 "/etc/mail/sendmail.cf doesn't exist; exiting"
 t_echo 3 "Could not save current semdmail.cf or could not find it"
 exit 1
fi

t_echo 3 " Checking for smrsh "
    if [ -f /sbin/smrsh -a -f /etc/mail/sendmail.cf ] ; then
      grep "smrsh" /etc/mail/sendmail.cf >/dev/null
        if [ $? -ne 0 ]; then
          t_echo 0 "      smrsh isn't set in /etc/mail/sendmail.cf  - FAILS CHECK"
          exit 1
        else
             t_echo 1 "      Smrsh is listed in /etc/mail/sendmail.cf  - PASSES CHECK"
        fi
    else
            t_echo 0 " smrsh not found in /sbin -  FAILS CHECK"
    fi
}

Fix() {
 
# Here is where we add in the option
 
if [ -f /etc/mail/sendmail.cf ]; then
 
 /bin/cp /etc/mail/sendmail.cf /etc/mail/sendmail.cf.titan2 >/dev/null
 
 if [ $? -eq 0 ]; then

#Check here for duplicate LogLevel line and whether LogLevel exists
#and if it exists the level should be higher than 5.
# 03 Sep 1999 Mitko Stoyanov

 smllevel=0
  
 if grep '^[^#][^#]*LogLevel'  \
  /etc/mail/sendmail.cf > /dev/null 2>&1 ; then
  smllevel="` nawk '
        BEGIN {
        llevcntr=0;
             }
        /^[^#]+LogLevel/ { 
        if ( match($0,/LogLevel[ ]*\=[ ]*[1-9]+/)) {
              llevcntr++;
              llev= substr($0, RSTART, RLENGTH);
              gsub(/ /, "", llev);
              gsub(/LogLevel/, "", llev);
              gsub(/\=/, "", llev);
                     }
                   }
              END {
              if (llevcntr == 1 || llevcntr == 0) {
                 print llev;
                        }
               else {  
                print "10000" 
                   }
              } ' /etc/mail/sendmail.cf `"

  if [ $? -ne 0 ]; then
        t_echo 3 " nawk script ERROR -  FIX FAILED"
        exit 1
  fi   

  #Add LogLevel=5 because LogLevel does not exist

  else
  t_echo 3 " Adding LogLevel=5 option..." 
	ed - /etc/mail/sendmail.cf <<- !
	/Options
	a
	         
	.
	a
	# Logging auth notices
	.
	a
	O LogLevel=5
	.
	w
	q
	!

  
  fi

if [ $smllevel -eq 10000 ];then
        t_echo 1 " Multiple LogLevel lines: FIX FAILED"
        exit 1
   fi

#Check whether LogLevel is less than 5 and raise it if necessary

if [ $smllevel -ge 5 ];then
        t_echo 1 " The LogLevel is already >= 5 : $smllevel - PASSES CHECK"
else
	ed - /etc/mail/sendmail.cf <<- !
	g/^\([^#][^#]*LogLevel\)[ ]*\=[ ]*[1-9]*/\1\=5 /g
	.
	w
	q
	!
 
   fi



if grep '^[ ]*Opgoaway' /etc/mail/sendmail.cf > /dev/null 2>&1; then
  t_echo 2 " Opgoaway is already in /etc/mail/sendmail.cf "
else
  t_echo 2 " Adding Opgoaway to /etc/mail/sendmail.cf...."
ed - /etc/mail/sendmail.cf <<- !
/Options
a
         
.
a
# Privacy Flags
.
a
Opgoaway
.
a
 
.
w
q
!
fi

 
 t_echo 2 "     "   
else
 t_echo 1 "        Could not backup /etc/mail/sendmail.cf - ERROR"
 exit 1
 fi
fi

t_echo 2 " Changing the sendmail shell to smrsh"
if [ -f /sbin/smrsh -a -f /etc/mail/sendmail.cf ]; then
	t_echo 2 " adding in smrsh to /etc/mail/sendmail.cf"

ed - /etc/mail/sendmail.cf <<- !
g/P=\/bin\/sh,/s//P=\/sbin\/smrsh,/g
w
q
!

else
        t_echo 1 " /sbin/smrsh does not exist - ERROR"
        exit 1
fi
 
} # End FixGoaway

action=$1
	case $action in
	-[Ii]*)
	Intro
	;;
	-[Ff]*)
	 Fix
	;;
	-[Vv]*)
	 Check
	;;
	*)
        t_echo 1 " ERROR:Invalid arg $action"
        t_echo 1 " ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
        t_echo 1 " "
	;;
esac

