:
# login_failed_retries.sh
#
# 2001-04-25 JKR Copy of syslog_failed_logins.sh, except updates the RETRIES 
#	variable.
# version 4.0.10

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt 
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001
#
# The copyright holder disclaims all responsibility or liability with 
# respect to its usage or its effect upon hardware or computer 
# systems, and maintains copyright as set out in the "LICENSE" 
# document which accompanies distribution. 

# How many login failures before exiting?
RF_LOGLIMIT=3

# setup
TITANHOME=`pwd`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
DATE=`/bin/date +%m%d%y%H%M`
SAVEFILES='/etc/default/login'
OS=`uname -r`

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

. misc_functions.sh

Intro() {

cat << EOF
 $MYNAME - This program modifies /etc/default/login taking advantage of
 Solaris 8's RETRIES variable, which determines the number of failed 
 logins that will be allowed before login exits.

 Titan sets RETRIES=$RF_LOGLIMIT

EOF

}

Fix() {

 
 FAILED_LOGINS=`grep -s "^RETRIES=" /etc/default/login`

if [ "$FAILED_LOGINS" != "RETRIES=$RF_LOGLIMIT" ]; then
  t_echo 1 "        System Failed Login retries set incorrectly. Fixing "
ed - /etc/default/login << EOEF
g/^RETRIES/s//#\ RETRIES/g
.
w
a
# Titan version 4.0 change
.
w
a
RETRIES=$RF_LOGLIMIT
.
w
q
EOEF
else
  t_echo 1 "         System Failed Login retries set correctly. - PASSES CHECK" 
fi

}


Check() {

if [ -f /etc/default/login ]; then

 FAILED_LOGINS=`grep -s "^RETRIES=" /etc/default/login`
 
  if [ "$FAILED_LOGINS" != "RETRIES=$RF_LOGLIMIT" ]; then

  t_echo 0 "        Failed Login retries set to $FAILED_LOGINS - FAILS CHECK"

        t_echo 3 "Titan Recommendation: (loginlog.sh -f) Also see syslog_failed_logins.sh."
        t_echo 3 "System should be set to at least to log failed login"
        t_echo 3 "attempts to a syslog."
         t_echo 3 "modify /etc/default/login "
        t_echo 3 "FROM: "
        t_echo 3 "        RETRIES=5 "
        t_echo 3 "TO: "
        t_echo 3 "        RETRIES=3 "
        t_echo 3 " "
        t_echo 3 "======================================================================== "
else
  t_echo 1 "        Failed login retries is set to $FAILED_LOGINS - PASSES CHECK"
  fi
else
  t_echo 0 "	    /etc/default/login does not exist -- FAILS CHECK"
fi

}


action=$1
	case ${action} in
	-[Ii]*)
	Intro
	;;
	 -[Ff]*)
	Fix
	;;
	-[Vv]*)
	Check
	;;
	*)
        t_echo 1 "        ERROR:Invalid arg $action"
        t_echo 1 "        ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
        t_echo 1 " "
	;;
	esac
#finis
