:
# psfix.sh
# version 3.0 Sep 25 11:21:02 PDT 1998
# version 3.0.6 Mon Mar 22 12:25:19 PST 1999 bpowell; chmod 1777 doesn't
# always work in solaris 2.6 and newer since /tmp has the setgid bit set
# see man chmod in 2.6 for details. Thus we do a g-s before the chmod 1777 to fix.
# version 3.4 Wed Feb 16 08:33:18 PST 2000 savefile variable added
# version 4.0

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt 
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000
#
# The copyright holder disclaims all responsibility or liability with 
# respect to its usage or its effect upon hardware or computer 
# systems, and maintains copyright as set out in the "LICENSE" 
# document which accompanies distribution. 

# setup
TITANHOME=`pwd`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
DATE=`/bin/date +%m%d%y%H%M`
SAVEFILES='/etc/rc3.d/S79tmpfix'
OS=`uname -r`

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

. misc_functions.sh

Intro() {

cat << EOF

 $MYNAME - This program creates /etc/rc3.d/S79tmpfix so that upon
 boot the /tmp directory will always have the sticky bit set mode 1777

EOF

}

Check() {

if [ -f /etc/rc3.d/S??tmpfix ]; then
   t_echo 2 " File /etc/rc3.d/S??tmpfix already exists - Checking config"
   grep "/usr/bin/chmod 1777 /tmp" /etc/rc3.d/S??tmpfix >/dev/null
   if [ $? -eq 0 ]; then
   t_echo 1 "        /tmp is mode 1777  - PASSES CHECK"
   else
   t_echo 0 "        /tmp is not mode 1777  - FAILS CHECK"
        t_echo 3 " "
        t_echo 3 "Titan Recommendation: (psfix.sh -f) Titan recommends setting the sticky bit on"
        t_echo 3 "the /tmp directory. This change only allow the owner of the (temporary) file the"  
        t_echo 3 "ability to delete it. This stops bad-guys from removing a root owned temporary"
        t_echo 3 "file and inserting a link to /etc/password or /etc/shadow instead."        t_echo 3 " "
        t_echo 3 "======================================================================== "

   exit 1
   fi
else
   t_echo 0 "       Could not find /etc/rc3.d/S??tmpfix - FAILS CHECK"
   exit 1
fi
}

Fix() {
if [ -f /etc/rc3.d/S??tmpfix ]; then
   t_echo 2 " File /etc/rc3.d/S??tmpfix already exists; exiting"
   exit 1
else 
   t_echo 2 " Creating /etc/rc3.d/S79tmpfix..."

/bin/cat << EOF >/etc/rc3.d/S79tmpfix
#!/bin/sh
#ident  "@(#)tmpfix 1.0    95/09/14"
 
if [ -d /tmp ]
then
/usr/bin/chmod g-s /tmp
/usr/bin/chmod 1777 /tmp
/usr/bin/chgrp sys /tmp
/usr/bin/chown sys /tmp
fi
EOF

    /usr/bin/chmod 755 /etc/rc3.d/S79tmpfix
   t_echo 3 " File /etc/rc3.d/S79tmpfix created"
fi

}

action=$1
case ${action} in
	-[Ii]*)
	Intro
	;;
	-[Ff]*)
	Fix
	;;
	-[Vv]*)
	Check
	;;
	*)
        t_echo 1 "       ERROR:Invalid arg $action"
        t_echo 1 "       ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
        t_echo 1 " "
;;
esac
