:
# tmpfs-fixsize.sh
# version 1.0 Apr 12 11:21:02 PDT 2000
# version 4.0 beta1

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt
# Archibald, and Dan Farmer 1996, 1997, 1998, 1999, 2000 ,2001
#
# The copyright holder disclaims all responsibility or liability with
# respect to its usage or its effect upon hardware or computer
# systems, and maintains copyright as set out in the "LICENSE"
# document which accompanies distribution.
#
# This module was written by Joachim.Knoke@germany.sun.com 
# Thanks to Thomas.Thissen@paderlinx.de for help with nawk
#
# KWH modified - this entire module was broken due to a small bug on two lines
#  Also changed the backup file to be /etc/vfstab.ORIG.$DATE to be more
#  consistent with other modules.  Finally, I changed the temporary file
#  location - it isn't really safe to use /tmp so I use / instead which
#  should be a little safer than /tmp.
 
TITANHOME=`pwd`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
DATE=`/bin/date +%m%d%y%H%M`
SAVEFILES='/etc/vfstab'

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi
. misc_functions.sh

# you may want to adapt the size of tmp fs for your needs here
TMP_SIZE="100m"

Intro() {
cat << EOF_INTRO
 
 $MYNAME - This script checks, wether /tmp is mounted into virtual memory.
 If it is not, nothing is done.
 If it is, and the mount option field of /etc/vfstab contains a dash
 the vfstab file is backed up and modified, so that there is a size 
 limitation of $TMP_SIZE. So users can not kill a whole system by exhausting 
 virtual memory with creating big files in /tmp.

EOF_INTRO
}

Check() {

# Check wether /tmp is in vfstab:
if [ -n "`cat /etc/vfstab | grep tmp`" ]; then
   # ok there is a tmp entry in vfstab
   # now check, if it is in virtual memory:
   if [ "`cat /etc/vfstab | grep tmp | awk '{print $1}'`" = "swap" ]; then
      # OK /tmp in in vm
      # check wether size is limited or not
      # KWH modified - the following line was broken
      if [ "`cat /etc/vfstab | grep tmp | awk '{print $7}'`" = "-" ]; then
	 # OK no options are given to mount. This must be changed by this script
	 t_echo 0  " /tmp is in virtual memory without limitation - FAILS CHECK"
        t_echo 3 " "
        t_echo 3 "Titan Recommendation: (tmpfs-fixsize.sh -f) Fix the size of tmpfs in /etc/vfstab"   
        t_echo 3 "This script checks, wether /tmp is mounted into virtual memory."
        t_echo 3 "If it is not, nothing is done.  If it is, and the mount option "
        t_echo 3 "field of /etc/vfstab contains a dash the vfstab file is backed up and modified,"
        t_echo 3 "so that there is a size limitation of 100m. So users can not kill a whole system"
        t_echo 3 "by exhausting virtual memory by creating big files in /tmp. "
        t_echo 3 " "
        t_echo 3 "======================================================================== "

      else
	 if [ -n "`cat /etc/vfstab | grep tmp | grep size`" ]; then
	   t_echo 1  "Size is set for tmp in virtual memory -  PASSES CHECK"
	 else
	    t_echo 1 "Some options are given to /tmp in virtual memory. Check /etc/vfstab if options contain size= - PASSES CHECK"
	 fi
      fi 
   else
      t_echo 1 "/tmp does not reside in virtual memory, nothing to be done - PASSES CHECK"
   fi

else
   # there is no entry for tmp in vfstab
   t_echo 1 "/tmp reside in root, nothing to be done - PASSES CHECK"
fi

}

Fix() {
if [ -n "`cat /etc/vfstab | grep tmp`" ]; then
   # KWH modified - the following line was broken
   if [ "`cat /etc/vfstab | grep tmp | awk '{print $1}'`" = "swap" ]; then
      if [ "`cat /etc/vfstab | grep tmp | awk '{print $7}'`" = "-" ]; then
	 # back up 
	 t_echo 2 "Modifying vfstab"
         # We should preserve the file permissions here
	 cp -p /etc/vfstab /etc/vfstab.ORIG.$DATE
	 if [ $? -ne 0 ]; then
            t_echo 1 " Error creating backup of vfstab"
	    exit 1
	 else
	    t_echo 2 " Backup done, now editing"
	 fi
	 chmod 0600 /etc/vfstab.ORIG.$DATE
	 cat /etc/vfstab | grep -v /tmp	> /vfstab.new.$$
	  cat /etc/vfstab | grep /tmp | nawk -v ASIZE="$TMP_SIZE" '{print $1"\t"$2"\t"$3"\t"$4"\t"$5"\t"$6"\tsize="ASIZE}' >> /vfstab.new.$$
	 t_echo 1 "# tmp size may need changes based on your needs. $TMP_SIZE is set by Titan module $MYNAME" >> /vfstab.new.$$
	 if [ $? -ne 0 ]; then
            t_echo 1 " Error editing vfstab file"
	    exit 2
         else 
	    t_echo 2 " editing done, now copying"
	 fi
         # We should preserve the file permissions here
	 cp -p /vfstab.new.$$ /etc/vfstab
	 if [ $? -ne 0 ]; then
            t_echo 1 " Error copying file"
	    exit 3
	 else
	    t_echo 2 " done, setting rights"
	    chmod 0644 /etc/vfstab
	    chown root:sys /etc/vfstab
	    rm /vfstab.new.$$
	 fi
	 t_echo 3 "Done ... "
      fi
   fi
fi
}


 
action=$1
case $action in
 -[Ff]*)
Fix
;;
 -[Vv]*)
Check
;;
 -[Ii]*)
Intro
;;
 
*)
        t_echo 1 "        ERROR:Invalid arg $action"
        t_echo 1 "        ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
 
        t_echo 1 " "
;;
esac

